@@ -98,7 +98,7 @@ class Domoticz(IPlugin):
 #				log.msg("resp  :  %s" % (req))				
 				log.msg("resp  :  %s" % (resp))
 				log.msg("response   :  %s" % (jsonreq))
-				for xx in jsonreq.result.length
+				for xx in jsonreq.result.length:
 					log.msg(" jsonreq - idx   :  %s" % (xx(idx)))
 					log.msg("   jsonreq - type   :  %s" % (xx(Type)))
 		if bodies == "":
